﻿/// <file>ControlSettings.xaml.cs</file>
/// 
/// <summary>Contains the control settings for the sample plugin.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces;
using Mathema.EmbeddedTestBench.Core.Interfaces.UI;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Interfaces;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Helper;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Resources;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.ViewModel;

using System;
using System.Globalization;
using System.Windows.Controls;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Controls
{
    /// <summary>
    /// This <see cref="Control"/> contains the individual settings ui elements of the <see cref="SamplePluginPlugin"/>.
    /// </summary>
    public partial class ControlSettings : UserControl, IControlSettings
    {
        #region private Variables

        /// <summary>
        /// Contains the view model of <see cref="ControlSettings"/> control of the python plugin.
        /// </summary>
        private readonly SettingsViewModel settingsWindowViewModel;

        #endregion private Variables

        #region Constructor

        /// <summary>
        /// Creates a <see cref="ControlSettings"/> object.
        /// </summary>
        public ControlSettings()
        {
            settingsWindowViewModel = new SettingsViewModel();
            InitializeComponent();
            Name = StringLUT.SettingsWindow_TabItemText;
            DataContext = settingsWindowViewModel;
        }

        #endregion Constructor

        #region Public interface methods

        /// <inheritdoc/>
        public void Close()
        {
            // Currently empty on purpose.
        }

        /// <inheritdoc/>
        public bool SupportsPluginSettings(IPluginSettings pluginSettings)
        {
            if (pluginSettings is null)
            {
                throw new ArgumentNullException(nameof(pluginSettings));
            }

            return pluginSettings is UiSettings;
        }

        /// <inheritdoc/>
        public void LoadFrom(IPluginSettings pluginSettings)
        {
            if (pluginSettings is null)
            {
                throw new ArgumentNullException(nameof(pluginSettings));
            }

            if (pluginSettings is ISamplePluginPluginSettings samplePluginSettings)
            {
                settingsWindowViewModel.LoadFrom(samplePluginSettings);
            }
            else
            {
                string exceptionMessage = string.Format(CultureInfo.CurrentCulture, StringLUT.Exception_WrongSettingsTypeInControlFormat, pluginSettings.GetType().FullName);
                throw new ArgumentException(exceptionMessage, nameof(pluginSettings));
            }
        }

        /// <inheritdoc/>
        public void SaveSettings(IPluginSettings pluginSettings)
        {
            if (pluginSettings is null)
            {
                throw new ArgumentNullException(nameof(pluginSettings));
            }

            if (pluginSettings is UiSettings pluginUiSettings)
            {
                settingsWindowViewModel.Save(pluginUiSettings);
            }
            else
            {
                string exceptionMessage = string.Format(CultureInfo.CurrentCulture, StringLUT.Exception_WrongSettingsTypeInControlFormat, pluginSettings.GetType().FullName);
                throw new ArgumentException(exceptionMessage, nameof(pluginSettings));
            }
        }

        #endregion Public interface methods
    }
}
