﻿/// <file>SamplePluginPlugin.cs</file>
/// 
/// <summary>Custom sample Detail View for strings.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

using Mathema.EmbeddedTestBench.Core.Attributes.UI;
using Mathema.EmbeddedTestBench.Core.TestExecutions;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes;

using System.Windows;
using System.Windows.Controls;

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Controls.DetailViews
{
    /// <summary>
    /// Interaktionslogik für StringResultEditor.xaml
    /// </summary>
    public partial class StringResultEditor : UserControl
    {
        #region Properties
        /// <summary>
        /// Names the details property of parent steptype
        /// </summary>
        [ResultDetailsValueDependencyProperty]
        public static readonly DependencyProperty DetailsValueDependencyProperty = DependencyProperty.Register(
            "DetailsValue", typeof(DoSampleWithDetailStep), typeof(StringResultEditor), new PropertyMetadata(null));

        /// <summary>
        /// ParentStepType
        /// </summary>
        public DoSampleWithDetailStep DetailsValue
        {
            get
            {
                return (DoSampleWithDetailStep)GetValue(DetailsValueDependencyProperty);
            }
            set { SetValue(DetailsValueDependencyProperty, value); }
        }

        /// <summary>
        /// Parent Test execution
        /// </summary>
        [ResultTestStepDependencyProperty]
        public static readonly DependencyProperty TestStepDependencyProperty = DependencyProperty.Register(
            "TestStep", typeof(TestStepExecution), typeof(StringResultEditor), new PropertyMetadata(null));

        /// <summary>
        /// Test execution
        /// </summary>
        public TestStepExecution TestStep
        {
            get { return (TestStepExecution)GetValue(TestStepDependencyProperty); }
            set { SetValue(TestStepDependencyProperty, value); }
        }

        #endregion Properties

        /// <summary>
        /// Constructor
        /// </summary>
        public StringResultEditor()
        {
            InitializeComponent();
            DataContext = this;
        }
    }
}
