﻿/// <file>CustomStringEditor.cs</file>
/// 
/// <summary>Represents a custom editor that allows to edit a string.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Attributes.UI;

using System.Collections.ObjectModel;
using System.Diagnostics.CodeAnalysis;
using System.Windows;
using System.Windows.Controls;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Controls.Editors
{
    /// <summary>
    /// Represents an editor that displays an <see cref="ObservableCollection{T}"/> of(string,string) instances.
    /// </summary>
    /// <remarks>
    /// This editor is not used.
    /// </remarks>
    [PropertyEditor(SamplePluginEditorGuids.CustomStringEditor)]
    [SuppressMessage("Microsoft.Maintainability", "CA1501:AvoidExcessiveInheritance", Justification = "Hierarchy level cannot be decreased because it's an UI class.")]
    public partial class CustomStringEditor : UserControl
    {
        #region Private static variables

        /// <summary>
        /// The <see cref="DependencyProperty"/> for the modules that are edited in this channel editor.
        /// </summary>
        [PropertyEditorEditValueDependencyProperty]
        public static readonly DependencyProperty EditValueDependencyProperty = DependencyProperty.Register(nameof(EditValue), typeof(string), typeof(CustomStringEditor), new PropertyMetadata(string.Empty));

        #endregion Private static variables

        #region Properties

        /// <summary>
        /// The editable value for this editor
        /// </summary>
        public string EditValue
        {
            get
            {
                return (string)GetValue(EditValueDependencyProperty);
            }

            set
            {
                SetValue(EditValueDependencyProperty, value);
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Creates a new and empty instance of this <see cref="CustomStringEditor"/> class.
        /// </summary>
        public CustomStringEditor()
        {
            InitializeComponent();
        }

        #endregion Constructors

    }
}
