﻿/// <file>SamplePluginDetailedResultsGuidResolver.cs</file>
/// 
/// <summary>SamplePluginDetailedResultsGuidResolver class.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Core.Interfaces.UI.Tests;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Controls.DetailViews;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Resources;

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Data;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Helper
{
    /// <summary>
    /// An implementation of the <see cref="IDetailedResultsGuidResolver"/> interface for this sample plugin.
    /// </summary>
    internal sealed class SamplePluginDetailedResultsGuidResolver : IDetailedResultsGuidResolver
    {
        #region Variables

        /// <summary>
        /// The <see cref="Guid"/> for the sample detailed editor.
        /// </summary>
        private readonly Guid stringDetailedEditorGuid;

        #endregion Variables

        #region Constructors

        /// <summary>
        /// Creates a new instance of this <see cref="SamplePluginDetailedResultsGuidResolver"/> class.
        /// </summary>
        public SamplePluginDetailedResultsGuidResolver()
        {
            stringDetailedEditorGuid = Guid.ParseExact(SamplePluginEditorGuids.SimpleStringResultEditor, "B");
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public bool CanBeResolved(Guid windowGuid)
        {
            return stringDetailedEditorGuid == windowGuid;
        }

        /// <inheritdoc/>
        public Window CreateDetailedResultsWindow(Guid windowGuid, DependencyProperty resultDetailsValueDependencyProperty, ITestStepType testStepType, Window owner, [Localizable(true)] string windowTitle)
        {
            if (!CanBeResolved(windowGuid))
            {
                throw new KeyNotFoundException(StringLUT.ERROR_GuidCannotBeResolved);
            }
            ArgumentNullException.ThrowIfNull(resultDetailsValueDependencyProperty);
            ArgumentNullException.ThrowIfNull(testStepType);
            ArgumentNullException.ThrowIfNull(owner);
            ArgumentNullException.ThrowIfNull(windowTitle);

            StringResultEditor stringResultEditor = new();

            Binding userControlBinding = new()
            {
                Source = testStepType,
                Mode = BindingMode.OneWay,
            };

            _ = BindingOperations.SetBinding(stringResultEditor, resultDetailsValueDependencyProperty, userControlBinding);

            stringResultEditor.HorizontalAlignment = HorizontalAlignment.Stretch;
            stringResultEditor.VerticalAlignment = VerticalAlignment.Stretch;

            Window returnedWindow = new()
            {
                Title = windowTitle,
                Owner = owner,
                Content = stringResultEditor,
                Width = 800,
                Height = 500,
                Style = Application.Current.FindResource("theme_WindowStyle") as Style,
                WindowStyle = WindowStyle.ToolWindow,
                WindowStartupLocation = WindowStartupLocation.CenterOwner
            };

            return returnedWindow;
        }

        /// <inheritdoc/>
        public DependencyProperty GetDetailsValueDependencyProperty(Guid windowGuid)
        {
            if (!CanBeResolved(windowGuid))
            {
                throw new KeyNotFoundException(StringLUT.ERROR_GuidCannotBeResolved);
            }

            return StringResultEditor.DetailsValueDependencyProperty;
        }

        #endregion Public methods
    }
}
