﻿/// <file>DoSampleWithDetailStepUiMetadata.cs</file>
/// 
/// <summary>The implementation of the <see cref="TestStepTypeUiMetadataBase"/> class for the <see cref="DoSampleWithDetailStep"/> class.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Steps;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Core.Interfaces.UI.Tests;
using Mathema.EmbeddedTestBench.Core.UI.Tests;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes.Metadata;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Controls.DetailViews;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Helper;

using System;
using System.ComponentModel;
using System.Windows;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Metadata
{
    /// <summary>
    /// The implementation of the <see cref="TestStepTypeUiMetadataBase"/> class for the <see cref="DoSampleWithDetailStep"/> class.
    /// </summary>
    internal sealed class DoSampleWithDetailStepUiMetadata : TestStepTypeUiMetadataBase
    {
        #region Properties

        /// <inheritdoc/>
        public override bool HasResultDetailsControl
        {
            get
            {
                return true;
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Initializes a new instance of this <see cref="DoSampleStepUiMetadata"/> class.
        /// </summary>
        public DoSampleWithDetailStepUiMetadata() : base(new DoSampleWithDetailStepMetadata())
        {
            // Empty on purpose.
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public override DoSampleWithDetailStepUiMetadata CreateDeepCopy()
        {
            return new();
        }

        /// <inheritdoc/>
        public override Window CreateWindowForTestStepTypeDetailResults(ITestStepType testStepType, ITestStepExecution testStepExecution, IDetailedResultsGuidResolver resolver, Window owner, [Localizable(true)] string windowTitle)
        {
            ArgumentNullException.ThrowIfNull(testStepType);
            ArgumentNullException.ThrowIfNull(testStepExecution);
            ArgumentNullException.ThrowIfNull(resolver);
            ArgumentNullException.ThrowIfNull(owner);
            ArgumentNullException.ThrowIfNull(windowTitle);

            SamplePluginDetailedResultsGuidResolver resultGuidResolver = new();

            return resultGuidResolver.CreateDetailedResultsWindow(Guid.ParseExact(SamplePluginEditorGuids.SimpleStringResultEditor, "B"), StringResultEditor.DetailsValueDependencyProperty, testStepType, owner, windowTitle);
        }

        #endregion Public methods
    }
}
