﻿/// <file>SamplePluginHardwareTypeUiProvider.cs</file>
/// 
/// <summary>An overwritten version of the <see cref="SamplePluginHardwareTypeProvider"/> that is needed for the plugin system.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.HardwareTypes.Metadata;

using System;
using System.Reflection;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.UI.Metadata
{
    /// <summary>
    /// An overwritten version of the <see cref="SamplePluginHardwareTypeProvider"/> that is needed for the plugin system (because the SamplePlugin UI plugin replaces the SamplePlugin plugin during the load of the plugins).
    /// </summary>
    internal sealed class SamplePluginHardwareTypeUiProvider : SamplePluginHardwareTypeProvider
    {
        #region Private static variables

        /// <summary>
        /// This assembly.
        /// </summary>
        private static readonly Assembly SamplePluginUiAssembly = Assembly.GetExecutingAssembly();

        #endregion Private static variables

        #region Constructors

        /// <summary>
        /// Initializes a new instance of this <see cref="SamplePluginHardwareTypeUiProvider"/> and fills the cache with the hardware from the SamplePlugin assembly.
        /// </summary>
        public SamplePluginHardwareTypeUiProvider()
        {
            // Empty on purpose: Everything is done in the base class.
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public override IPlugin SourcePlugin(IPluginResolver pluginResolver)
        {
            ArgumentNullException.ThrowIfNull(pluginResolver);

            return pluginResolver.GetPluginFromLoadedAssembly(SamplePluginUiAssembly);
        }

        #endregion Public methods
    }
}
