﻿/// <file>ISampleHardwareType.cs</file>
/// 
/// <summary>Sample interface for a hardware type.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces.Hardwares.Types;

using System;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Interfaces
{
    /// <summary>
    /// Represents the sample hardware type.
    /// </summary>
    public interface ISampleHardwareType : IHardwareType
    {

        #region Properties
        /* Hardware specific properties, which are not contained in the base IHardwareType interface
         * 
         */

        /// <summary>
        /// Gets or sets the ComPort name where the sample hardware is connected to.
        /// </summary>
        /// <exception cref="ArgumentNullException">If the provided value is <see langword="null"/>.</exception>
        /// <exception cref="InvalidOperationException">If you tried to change the name when the ComPort is already opened.</exception>
        string ComPortName { get; set; }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Opens the internal ComPort to the sample hardware.
        /// </summary>
        void OpenComPort();

        /// <summary>
        /// Closes the internal ComPort to the sample hardware.
        /// </summary>
        void CloseComPort();

        /// <summary>
        /// Writes the given <paramref name="data"/>.
        /// </summary>
        /// <param name="data">Data to write</param>
        void WriteData(string data);

        #endregion Methods
    }
}
