﻿/// <file>ArgumentValidationResult.cs</file>
/// 
/// <summary>Implementation of the <see cref="IArgumentValidationResult"/> interface for the sample plugin.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces.CommandLine;

using System.ComponentModel;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.CommandLine
{
    /// <summary>
    /// Implementation of the <see cref="IArgumentValidationResult"/> interface for the sample plugin.
    /// </summary>
    internal sealed class ArgumentValidationResult : IArgumentValidationResult
    {
        #region Properties

        /// <inheritdoc/>
        public bool IsValid { get; }

        /// <inheritdoc/>
        public string? ValidationMessage { get; }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Initializes a new instance of this <see cref="ArgumentValidationResult"/> that represents a successful validation.
        /// </summary>
        public ArgumentValidationResult()
        {
            IsValid = true;
        }

        /// <summary>
        /// Initializes a new instance of this <see cref="ArgumentValidationResult"/> that represents an unsuccessful validation.
        /// </summary>
        /// <param name="validationMessage">The message that describes the validation result.</param>
        public ArgumentValidationResult([Localizable(true)] string validationMessage)
        {
            IsValid = false;
            ValidationMessage = validationMessage;
        }

        #endregion Constructors
    }
}
