﻿/// <file>PythonArgumentsOptionsProvider.cs</file>
/// 
/// <summary>An implementation of the <see cref="ICliArgumentsOptionsProvider"/> for the sample plugin.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces.CommandLine;

using System;
using System.Collections.Generic;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.CommandLine
{
    /// <summary>
    /// An implementation of the <see cref="ICliArgumentsOptionsProvider"/> for the sample plugin.
    /// </summary>
    internal sealed class SamplePluginArgumentsOptionsProvider : ICliArgumentsOptionsProvider
    {
        #region  Variables

        /// <summary>
        /// The python executable argument.
        /// </summary>
        private readonly SamplePluginExecutableArgument samplePluginExecutableArgument;

        #endregion  Variables

        #region Constructors

        /// <summary>
        /// Initializes a new instance of this <see cref="SamplePluginArgumentsOptionsProvider"/> class.
        /// </summary>
        public SamplePluginArgumentsOptionsProvider()
        {
            samplePluginExecutableArgument = new SamplePluginExecutableArgument();
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public IReadOnlyList<ICommandLineArgument> GetCommandLineArguments()
        {
            return new[] { samplePluginExecutableArgument };
        }

        /// <inheritdoc/>
        public IReadOnlyList<ICommandLineOption> GetCommandLineOptions()
        {
            return Array.Empty<ICommandLineOption>();
        }

        #endregion Public methods
    }
}
