﻿/// <file>SamplePluginExecutableArgument.cs</file>
/// 
/// <summary>SamplePluginExecutableArgument class.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core.Interfaces;
using Mathema.EmbeddedTestBench.Core.Interfaces.CommandLine;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.Helper;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Resources;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.CommandLine
{
    /// <summary>
    /// Represents the command line argument that allows the user to specify the location of a dummy executable that is needed by the sample plugin executable (only as example not really needed).
    /// </summary>
    internal sealed class SamplePluginExecutableArgument : ICommandLineArgument
    {
        #region Private const variables

        /// <summary>
        /// The name of this argument.
        /// </summary>
        private const string ArgumentName = "--SamplePluginDemoExecutable";

        /// <summary>
        /// The alias for <see cref="ArgumentName"/>.
        /// </summary>
        private const string ArgumentAliasName = "-spde";

        #endregion Private const variables

        #region Properties

        /// <inheritdoc/>
        public string Name
        {
            get
            {
                return ArgumentName;
            }
        }

        /// <inheritdoc/>
        public string Description
        {
            get
            {
                return StringLUT.ArgumentDescriptionSamplePluginDemoExecutable;
            }
        }

        /// <inheritdoc/>
        public bool IsRequired
        {
            get
            {
                return false;
            }
        }

        /// <inheritdoc/>
        public IReadOnlyCollection<string> AdditionalAliases
        {
            get
            {
                return new[] { ArgumentAliasName };
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Initializes a new and empty instance of this <see cref="SamplePluginExecutableArgument"/> class.
        /// </summary>
        public SamplePluginExecutableArgument() { }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public IArgumentValidationResult ValidateArgumentValue(string? argumentValue)
        {
            if (string.IsNullOrWhiteSpace(argumentValue))
            {
                return new ArgumentValidationResult(StringLUT.ArgumentValidationSamplePluginDemoExecutableNotProvided);
            }
            return new ArgumentValidationResult();
        }

        /// <inheritdoc/>
        public Task ExecuteArgument(string argumentValue, IReadOnlyList<IPluginSettings> pluginSettings)
        {
            if (pluginSettings is null)
            {
                throw new ArgumentNullException(nameof(pluginSettings));
            }

            SamplePluginSettings? sampleSettings = (SamplePluginSettings?)pluginSettings.FirstOrDefault(pluginSettings => pluginSettings is SamplePluginSettings);

            ArgumentNullException.ThrowIfNull(sampleSettings);

            sampleSettings.SamplePluginSettingBool = true;
            sampleSettings.SamplePluginSettingString = "string";
            sampleSettings.SamplePluginSettingNumber = 42;

            return Task.CompletedTask;
        }

        #endregion Public methods
    }
}
