﻿/// <file>SampleHardwareTypeMetadata.cs</file>
/// 
/// <summary>The implementation of the <see cref="IHardwareTypeMetadata"/> for the sample hardware type.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core;
using Mathema.EmbeddedTestBench.Core.Interfaces.Hardwares;
using Mathema.EmbeddedTestBench.Core.Interfaces.Hardwares.Types;
using Mathema.EmbeddedTestBench.Core.Model.Hardwares;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Resources;

using System;
using System.Collections.Generic;
using System.ComponentModel;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.HardwareTypes.Metadata
{
    /// <summary>
    /// The implementation of the <see cref="IHardwareTypeMetadata"/> for the <see cref="SampleHardwareType"/> class.
    /// </summary>
    public sealed class SampleHardwareTypeMetadata : IHardwareTypeMetadata
    {
        #region Properties

        /// <inheritdoc/>
        public Guid ID
        {
            get
            {
                return Guid.ParseExact("{00d37293-83f8-4228-8b4a-3b3e5e36185d}", "B");
            }
        }

        /// <inheritdoc/>
        [Localizable(true)]
        public string DisplayName
        {
            get
            {
                return StringLUT.STEP_PROP_SampleHardware_DisplayName;
            }
        }

        /// <inheritdoc/>
        [Localizable(true)]
        public string Description
        {
            get
            {
                return StringLUT.STEP_PROP_SampleHardware_Description;
            }
        }

        /// <inheritdoc/>
        public string ReferenceName
        {
            get
            {
                return nameof(SampleHardwareType);
            }
        }

        /// <inheritdoc/>
        public IEnumerable<IHardwarePropertyMetadata> HardwareProperties
        {
            get
            {
                yield return new SimpleHardwarePropertyMetadata(Guid.ParseExact(CoreEditorGuids.PortNameEditor, "B"), nameof(SampleHardwareType.ComPortName), false, StringLUT.HWTYPE_PROPERTY_ComPortName_DisplayName, StringLUT.HWTYPE_PROPERTY_ComPortName_Description);
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Creates a new instance of this <see cref="SampleHardwareTypeMetadata"/> class.
        /// </summary>
        public SampleHardwareTypeMetadata()
        {
            // Empty on purpose.
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public IHardwareTypeMetadata CreateDeepCopy()
        {
            return new SampleHardwareTypeMetadata();
        }

        /// <inheritdoc/>
        public IHardwareType CreateHardwareType(IHardware hardware)
        {
            ArgumentNullException.ThrowIfNull(hardware);

            return new SampleHardwareType(hardware);
        }

        /// <inheritdoc/>
        public bool CreatesEquivalentHardwareTypes(IHardwareType hardwareType)
        {
            ArgumentNullException.ThrowIfNull(hardwareType);

            return hardwareType.GetType().IsEquivalentTo(typeof(SampleHardwareType));
        }

        /// <inheritdoc/>
        public bool Equals(IHardwareTypeMetadata? other)
        {
            if (other is null)
            {
                return false;
            }

            return ID.Equals(other.ID);
        }

        /// <inheritdoc/>
        public override bool Equals(object? obj)
        {
            return Equals(obj as IHardwareTypeMetadata);
        }

        /// <inheritdoc/>
        public override int GetHashCode()
        {
            return ID.GetHashCode();
        }

        /// <inheritdoc/>
        public override string ToString()
        {
            return $"{ReferenceName}: {DisplayName}";
        }

        #endregion Public methods
    }
}
