﻿/// <file>DoSampleWithDetailStep.cs</file>
/// 
/// <summary>Simple sample test step with detail result view.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#region Using

using Mathema.EmbeddedTestBench.Core.Enums.Enums;
using Mathema.EmbeddedTestBench.Core.Interfaces.Export;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Steps;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Core.Model.Tests;
using Mathema.EmbeddedTestBench.Core.Model.Tests.Types;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Resources;

using System;
using System.Collections.Generic;
using System.Globalization;
using System.Runtime.Serialization;
using System.Threading;
using System.Threading.Tasks;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes
{
    /// <summary>
    /// Simple sample test step with detail result view.
    /// </summary>
    [DataContract(IsReference = true)]
    public sealed class DoSampleWithDetailStep : TestStepTypeBase
    {
        #region Variables

        private int doSampleNumber;
        private string demoString;
        private string resultString;

        #endregion Variables

        #region Properties

        /// <summary>
        /// Sample property for an integer
        /// </summary>
        [DataMember]
        public int DoSampleNumber
        {
            get
            {
                return doSampleNumber;
            }
            set
            {
                SetProperty(ref doSampleNumber, value);
            }
        }

        /// <summary>
        /// Sample property for a string
        /// </summary>
        [DataMember]
        public string DemoString
        {
            get
            {
                return demoString;
            }
            set
            {
                SetProperty(ref demoString, value);
            }
        }

        /// <inheritdoc/>
        public override bool IsDirty
        {
            get
            {
                return base.IsDirty;
            }
        }

        /// <summary>
        /// Contains the result visible in detail window
        /// </summary>
        [DataMember(EmitDefaultValue = false)]
        public string ResultString
        {
            get { return resultString; }
            set { SetProperty(ref resultString, value); }

        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Creates a new and empty instance of this <see cref="DoSampleWithDetailStep"/> class.
        /// </summary>
        /// <param name="testStep">The parent <see cref="ITestStep"/> instance.</param>
        /// <exception cref="ArgumentNullException">If <paramref name="testStep"/> is <see langword="null"/>.</exception>
        public DoSampleWithDetailStep(ITestStep testStep) : base(testStep, StringLUT.STEP_DoSampleWithDetailStep_DisplayName)
        {
            DoSampleNumber = -1;
            DemoString = "demodaten";
        }

        /// <summary>
        /// Private constructor for the <see cref="CreateDeepCopy(ITestStep)"/> method to copy the provided <paramref name="doSampleStep"/>..
        /// </summary>
        /// <param name="testStep">The parent <see cref="ITestStep"/> instance.</param>
        /// <param name="doSampleStep">The <see cref="DoSampleWithDetailStep"/> instance for the copy.</param>
        private DoSampleWithDetailStep(ITestStep testStep, DoSampleWithDetailStep doSampleStep) : base(testStep, StringLUT.STEP_DoSampleWithDetailStep_DisplayName)
        {
            ResultString = doSampleStep.ResultString;
            DoSampleNumber = doSampleStep.doSampleNumber;
            DemoString = doSampleStep.demoString;
        }

        #endregion Constructors

        #region Private helper methods


        /// <inheritdoc/>
        protected override void RemoveDirtyStateFromChildElements()
        {
            base.RemoveDirtyStateFromChildElements();
        }

        /// <inheritdoc/>
        protected override async Task ExecuteInternal(ITestExecutionContext context, IProgress<ITestExecutionProgress> progress, CancellationToken cancellationToken)
        {
            ArgumentNullException.ThrowIfNull(progress);

            //Do Stuff of the TestStep
            await doWork(cancellationToken).ConfigureAwait(false);

            if (doSampleNumber > 100)
            {
                progress.Report(new TestExecutionProgress(1, TestExecutionState.Passed, demoString));
            }
            else
            {
                progress.Report(new TestExecutionProgress(1, TestExecutionState.Failed, demoString));
            }
            AddLoremIpsum();
        }

        /// <summary>
        /// Helperfunction
        /// </summary>
        private void AddLoremIpsum()
        {
            ResultString += @"Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.

Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.

Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat.Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.

Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum.Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat.

Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis.

At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.Lorem ipsum dolor sit amet, consetetur sadipscing elitr, At accusam aliquyam diam diam dolore dolores duo eirmod eos erat, et nonumy sed tempor et et invidunt justo labore Stet clita ea et gubergren, kasd magna no rebum.sanctus sea sed takimata ut vero voluptua.est Lorem ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur";
        }

        /// <summary>
        /// Sample for an action within a steptype
        /// </summary>
        /// <param name="cancellationToken"><see cref="CancellationToken"/> to allow the abortion of the steptype</param>
        /// <returns></returns>
        private static async Task doWork(CancellationToken cancellationToken)
        {
            await Task.Delay(500, cancellationToken).ConfigureAwait(false);
        }

        #endregion Private helper methods

        #region Public methods

        /// <inheritdoc/>
        public override ITestStepType CreateDeepCopy(ITestStep parent)
        {
            ArgumentNullException.ThrowIfNull(parent);

            return new DoSampleWithDetailStep(parent, this);
        }

        /// <inheritdoc/>
        public override string GetPropertyDisplayValue(ITestStepPropertyMetadata propMetadata)
        {
            ArgumentNullException.ThrowIfNull(propMetadata);
            string result = propMetadata.Name switch
            {
                nameof(ResultString) => ResultString,
                nameof(DemoString) => DemoString,
                nameof(DoSampleNumber) => DoSampleNumber.ToString(CultureInfo.InvariantCulture),
                _ => base.GetPropertyDisplayValue(propMetadata)
            };

            return result;
        }

        /// <inheritdoc/>
        public override void WriteToXml(IExportElementDecider decider, ICollection<KeyValuePair<string, string>> parameters, IExporter exporter, CancellationToken cancellationToken)
        {
            ArgumentNullException.ThrowIfNull(decider);
            ArgumentNullException.ThrowIfNull(exporter);

            cancellationToken.ThrowIfCancellationRequested();

            exporter.CreateStepPropertyKeyValueCaptionEntries(nameof(DoSampleNumber), StringLUT.DoSampleNumber_DisplayName, DoSampleNumber.ToString(CultureInfo.InvariantCulture), cancellationToken);
            exporter.CreateStepPropertyKeyValueCaptionEntries(nameof(DemoString), StringLUT.StuffStrings, DemoString, cancellationToken);

            if (decider.CurrentExportType == ExportType.TestPlan)
            {
                exporter.CreateStepPropertyKeyValueCaptionEntries(nameof(ResultString), StringLUT.ResultString, ResultString.ToString(CultureInfo.InvariantCulture), cancellationToken);
            }
        }

        #endregion Public methods

    }
}
