﻿/// <file>ChangeMuxChannelsStepMetadata.cs</file>
/// 
/// <summary>The test step type metadata for the <see cref="DoSampleStep"/> class.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core;
using Mathema.EmbeddedTestBench.Core.Enums.Enums;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Steps;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Core.Model.Tests;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Interfaces;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Resources;

using System;
using System.Collections.Generic;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes.Metadata
{
    /// <summary>
    /// The test step type metadata for the <see cref="DoSampleStep"/> class.
    /// </summary>
    public sealed class DoSampleStepMetadata : SamplePluginTestStepTypeMetadataBase
    {
        #region Properties

        /// <inheritdoc/>
        public override string DisplayName
        {
            get
            {
                return StringLUT.STEP_DoSampleStep_DisplayName;
            }
        }

        /// <inheritdoc/>
        public override string Description
        {
            get
            {
                return StringLUT.STEP_DoSampleStep_Description;
            }
        }

        /// <inheritdoc/>
        public override IEnumerable<ITestStepPropertyMetadata> Properties
        {
            get
            {
                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Input, typeof(ISampleHardwareType), Guid.ParseExact(CoreEditorGuids.HardwareEditor, "B"), nameof(DoSampleStep.SampleHardware), false, StringLUT.STEP_PROP_SampleHardware_DisplayName, StringLUT.STEP_PROP_SampleHardware_Description);
                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Input, typeof(int), Guid.ParseExact(CoreEditorGuids.NumberEditor, "B"), nameof(DoSampleStep.DoNumber), false, StringLUT.DoSampleNumber_DisplayName, StringLUT.STEP_PROP_DoSampleNumber_Description);

                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Input, typeof(string), Guid.ParseExact(SamplePluginEditorGuids.CustomStringEditor, "B"), nameof(DoSampleStep.DemoString), false, StringLUT.StuffStrings, StringLUT.STEP_PROP_StuffStrings_Description);

            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Default constructor.
        /// </summary>
        public DoSampleStepMetadata() : base("{a1cf2a68-f930-4b47-bcc7-b8751098749b}")
        {
            // Empty on purpose.
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public override DoSampleStepMetadata CreateDeepCopy()
        {
            return new();
        }

        /// <inheritdoc/>
        public override DoSampleStep CreateTestStepType(ITestStep testStep)
        {
            ArgumentNullException.ThrowIfNull(testStep);

            return new(testStep);
        }

        /// <inheritdoc/>
        public override bool IsCompatible(ITestStepType testStepType)
        {
            ArgumentNullException.ThrowIfNull(testStepType);

            return testStepType.GetType() == typeof(DoSampleStep);
        }

        #endregion Public methods
    }
}
