﻿/// <file>DoSampleWithDetailStepMetadata.cs</file>
/// 
/// <summary>The test step type metadata for the <see cref="DoSampleWithDetailStep"/> class.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core;
using Mathema.EmbeddedTestBench.Core.Enums.Enums;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Steps;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Core.Model.Tests;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Resources;

using System;
using System.Collections.Generic;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes.Metadata
{
    /// <summary>
    /// The test step type metadata for the <see cref="DoSampleWithDetailStep"/> class.
    /// </summary>
    public sealed class DoSampleWithDetailStepMetadata : SamplePluginTestStepTypeMetadataBase
    {
        #region Properties

        /// <inheritdoc/>
        public override string DisplayName
        {
            get
            {
                return StringLUT.STEP_DoSampleWithDetailStep_DisplayName;
            }
        }

        /// <inheritdoc/>
        public override string Description
        {
            get
            {
                return StringLUT.STEP_DoSampleWithDetailStep_Description;
            }
        }

        /// <inheritdoc/>
        public override IEnumerable<ITestStepPropertyMetadata> Properties
        {
            get
            {
                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Input, typeof(int), Guid.ParseExact(CoreEditorGuids.NumberEditor, "B"), nameof(DoSampleWithDetailStep.DoSampleNumber), false, StringLUT.DoSampleNumber_DisplayName, StringLUT.STEP_PROP_DoSampleNumber_Description);

                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Input, typeof(string), Guid.ParseExact(CoreEditorGuids.StringEditor, "B"), nameof(DoSampleWithDetailStep.DemoString), false, StringLUT.StuffStrings, StringLUT.STEP_PROP_StuffStrings_Description);

                yield return new SimpleTestStepPropertyMetadata(StepPropertyDirection.Output, typeof(string), Guid.ParseExact(SamplePluginEditorGuids.SimpleStringResultEditor, "B"), nameof(DoSampleWithDetailStep.ResultString), false, StringLUT.ResultString, StringLUT.STEP_PROP_ResultString_Description);
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Default constructor.
        /// </summary>
        public DoSampleWithDetailStepMetadata() : base("{b787b3e9-a21a-495a-9102-8b1f8df7a89e}")
        {
            // Empty on purpose.
        }

        #endregion Constructors

        #region Public methods

        /// <inheritdoc/>
        public override DoSampleWithDetailStepMetadata CreateDeepCopy()
        {
            return new();
        }

        /// <inheritdoc/>
        public override DoSampleWithDetailStep CreateTestStepType(ITestStep testStep)
        {
            ArgumentNullException.ThrowIfNull(testStep);

            return new(testStep);
        }

        /// <inheritdoc/>
        public override bool IsCompatible(ITestStepType testStepType)
        {
            ArgumentNullException.ThrowIfNull(testStepType);

            return testStepType.GetType() == typeof(DoSampleWithDetailStep);
        }

        #endregion Public methods
    }
}
