﻿/// <file>SamplePluginPlugin.cs</file>
/// 
/// <summary>The sample plugin which shows how to create your own plugins.</summary>
/// 
/// <copyright>Copyright (c) MATHEMA GmbH 2024</copyright>
/// 
/// <autor>Dominik Dinkel [DD]</autor>
/// <date>12.04.2024</date>
/// <fileversion>1.0.0.0</fileversion>
/// <revisions>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">Created.</revision>
///     <revision initials="DD" date="12.04.2024" fileversion="1.0.0.0">First finished version.</revision>
/// </revisions>

#nullable enable

#region Using

using Mathema.EmbeddedTestBench.Core;
using Mathema.EmbeddedTestBench.Core.Interfaces;
using Mathema.EmbeddedTestBench.Core.Interfaces.CommandLine;
using Mathema.EmbeddedTestBench.Core.Interfaces.Hardwares.Types;
using Mathema.EmbeddedTestBench.Core.Interfaces.Tests.Types;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.CommandLine;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.HardwareTypes.Metadata;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.Helper;
using Mathema.EmbeddedTestBench.Plugin.SamplePlugin.Model.StepTypes.Metadata;

using System;
using System.Reflection;

#endregion Using

namespace Mathema.EmbeddedTestBench.Plugin.SamplePlugin
{
    /// <summary>
    /// The sample plugin.
    /// </summary>
    public sealed class SamplePluginPlugin : PluginBase
    {
        #region Variables

        /// <summary>
        /// The assembly of this class.
        /// </summary>
        private readonly Assembly thisAssembly;

        /// <summary>
        /// The <see cref="AssemblyTitleAttribute"/> of this assembly needed to retrieve the title of this assembly.
        /// </summary>
        private readonly AssemblyTitleAttribute assemblyTileAttribute;

        /// <summary>
        /// The <see cref="AssemblyCompanyAttribute"/> of this assembly to retrieve the company of this assembly.
        /// </summary>
        private readonly AssemblyCompanyAttribute assemblyCompanyAttribute;

        /// <summary>
        /// Unique identifier for plugin
        /// </summary>
        private readonly Guid identifier = new("{592a14d9-fe84-4c16-93ea-d9c622efc561}");

        #endregion Variables

        #region Properties

        /// <inheritdoc/>
        public override string DisplayName
        {
            get
            {
                return assemblyTileAttribute.Title;
            }
        }

        /// <inheritdoc/>
        public override string Vendor
        {
            get
            {
                return assemblyCompanyAttribute.Company;
            }
        }

        /// <inheritdoc/>
        public override Version Version { get; }

        /// <inheritdoc/>
        public override Guid Identifier
        {
            get
            {
                return identifier;
            }
        }

        #endregion Properties

        #region Constructors

        /// <summary>
        /// Creates a new instance of this <see cref="SamplePluginPlugin"/> class.
        /// </summary>
        public SamplePluginPlugin()
        {
            thisAssembly = Assembly.GetExecutingAssembly();
            assemblyTileAttribute = thisAssembly.GetCustomAttribute<AssemblyTitleAttribute>()!;
            assemblyCompanyAttribute = thisAssembly.GetCustomAttribute<AssemblyCompanyAttribute>()!;
            Version = thisAssembly.GetName().Version!;
        }

        #endregion Constructors

        #region Methods

        /// <inheritdoc/>
        public override IHardwareTypeProvider GetHardwareTypeProvider()
        {
            return new SamplePluginHardwareTypeProvider();
        }

        /// <inheritdoc/>
        public override ITestStepTypeProvider GetTestStepTypeProvider()
        {
            return new SamplePluginTestStepTypeProvider();
        }

        /// <inheritdoc/>
        public override IPluginSettings? RetrieveSettings()
        {
            return new SamplePluginSettings();
        }

        /// <inheritdoc/>
        public override ICliArgumentsOptionsProvider? GetCliProvider()
        {
            return new SamplePluginArgumentsOptionsProvider();
        }

        #endregion Methods
    }
}
